MatchingRuleCategory

Struct MatchingRuleCategory 

pub struct MatchingRuleCategory {
    pub name: Category,
    pub rules: HashMap<DocPath, RuleList>,
}
Data structure for representing a category of matching rules

Fields

name: Category

Name of the category

rules: HashMap<DocPath, RuleList>

Matching rules for this category

Implementations

Source

impl MatchingRuleCategory

pub fn empty<S>(name: S) -> MatchingRuleCategory
where S: Into<Category>,

Creates an empty category

pub fn equality<S>(name: S) -> MatchingRuleCategory
where S: Into<Category>,

Creates a default category

pub fn is_empty(&self) -> bool

If the matching rules in the category are empty

pub fn is_not_empty(&self) -> bool

If the matching rules in the category are not empty

pub fn rule_from_json( &mut self, key: DocPath, matcher_json: &Value, rule_logic: RuleLogic, ) -> Result<()>

Adds a rule from the Value representation

pub fn add_rule( &mut self, key: DocPath, matcher: MatchingRule, rule_logic: RuleLogic, )

Adds a rule to this category

pub fn filter<F>(&self, predicate: F) -> MatchingRuleCategory
where F: Fn(&(&DocPath, &RuleList)) -> bool,

Filters the matchers in the category by the predicate, and returns a new category

pub fn to_v3_json(&self) -> Value

Returns a JSON Value representation in V3 format

pub fn to_v2_json(&self) -> HashMap<String, Value>

Returns a JSON Value representation in V2 format

pub fn type_matcher_defined(&self) -> bool

If there is a type matcher defined for the category

pub fn values_matcher_defined(&self) -> bool

If there is a values matcher defined in the rules

pub fn matcher_is_defined(&self, path: &[&str]) -> bool

If there is a matcher defined for the path

pub fn resolve_matchers_for_path(&self, path: &[&str]) -> MatchingRuleCategory

filters this category with all rules that match the given path for categories that contain collections (eg. bodies, headers, query parameters). Returns self otherwise.

pub fn select_best_matcher(&self, path: &[&str]) -> RuleList

Selects the best matcher for the given path by calculating a weighting for each one

pub fn as_rule_list(&self) -> RuleList

Returns this category as a matching rule list. Returns a None if there are no rules

pub fn add_rules_from_json(&mut self, rules: &Value) -> Result<()>

Adds the rules to the category from the provided JSON

pub fn add_v3_rules_from_json(&mut self, rules: &Value) -> Result<()>

Adds the rules to the category from the provided JSON in V3+ format

pub fn generators(&self) -> HashMap<DocPath, Generator>

Returns any generators associated with these matching rules

pub fn rename<S>(&self, name: S) -> Self
where S: Into<Category>,

Clones this category with the new name

pub fn add_rules(&mut self, category: MatchingRuleCategory)

Add all the rules from the provided rules