pub struct DocPath { /* private fields */ }Implementations
Sourceimpl DocPath
impl DocPath
Sourcepub fn new(expr: impl Into<String>) -> Result<Self>
pub fn new(expr: impl Into<String>) -> Result<Self>
Construct a new document path from the provided string path
Sourcepub fn new_unwrap(expr: &'static str) -> Self
pub fn new_unwrap(expr: &'static str) -> Self
Infallible construction for when the expression is statically known, intended for unit tests.
Invalid expressions will still cause panics.
Sourcepub fn empty() -> Self
pub fn empty() -> Self
Construct a new DocPath with an empty expression.
Warning: do not call any of the push_* methods on this DocPath,
as that would create an expression with invalid syntax
(because it would be missing the Root token).
Sourcepub fn from_tokens<I>(tokens: I) -> Selfwhere
I: IntoIterator<Item = PathToken>,
pub fn from_tokens<I>(tokens: I) -> Selfwhere
I: IntoIterator<Item = PathToken>,
Construct a new DocPath from a list of tokens
Sourcepub fn last(&self) -> Option<PathToken>
pub fn last(&self) -> Option<PathToken>
Returns the last item in the path. Will panic if the path is empty.
Sourcepub fn first_field(&self) -> Option<&str>
pub fn first_field(&self) -> Option<&str>
Extract the string contents of the first Field token. For use with Header and Query DocPaths.
Sourcepub fn last_field(&self) -> Option<&str>
pub fn last_field(&self) -> Option<&str>
Extract the string contents of the last Field token.
Sourcepub fn is_root(&self) -> bool
pub fn is_root(&self) -> bool
If this path is the root path (it has only one element, the root token $).
Sourcepub fn is_wildcard(&self) -> bool
pub fn is_wildcard(&self) -> bool
The path is a wildcard path if it ends in a star (*)
Sourcepub fn path_weight(&self, path: &[&str]) -> (usize, usize)
pub fn path_weight(&self, path: &[&str]) -> (usize, usize)
Calculates the path weight for this path expression and a given path. Returns a tuple of the calculated weight and the number of path tokens matched.
Sourcepub fn matches_path(&self, path: &[&str]) -> bool
pub fn matches_path(&self, path: &[&str]) -> bool
If this path matches the given path. It will match if the calculated path weight is greater than zero (which means at least one token matched).
Sourcepub fn matches_path_exactly(&self, path: &[&str]) -> bool
pub fn matches_path_exactly(&self, path: &[&str]) -> bool
If the path matches the given path (the calculated path weight is greater than zero) and both paths have the same length.
Sourcepub fn join(&self, part: impl Into<String>) -> Self
pub fn join(&self, part: impl Into<String>) -> Self
Creates a new path by cloning this one and pushing the string onto the end
Sourcepub fn join_index(&self, index: usize) -> Self
pub fn join_index(&self, index: usize) -> Self
Creates a new path by cloning this one and joining the index onto the end. Paths that end
with * will have the * replaced with the index.
Sourcepub fn join_field<S: Into<String>>(&self, name: S) -> Self
pub fn join_field<S: Into<String>>(&self, name: S) -> Self
Creates a new path by cloning this one and joining the field onto the end. Paths that end
with * will have the * replaced with the field.
Sourcepub fn push_field(&mut self, field: impl Into<String>) -> &mut Self
pub fn push_field(&mut self, field: impl Into<String>) -> &mut Self
Mutates this path by pushing a field value onto the end.
Sourcepub fn push_index(&mut self, index: usize) -> &mut Self
pub fn push_index(&mut self, index: usize) -> &mut Self
Mutates this path by pushing an index value onto the end.
Sourcepub fn push_star(&mut self) -> &mut Self
pub fn push_star(&mut self) -> &mut Self
Mutates this path by pushing a star value onto the end.
Sourcepub fn push_star_index(&mut self) -> &mut Self
pub fn push_star_index(&mut self) -> &mut Self
Mutates this path by pushing a star index value onto the end.
Sourcepub fn push(&mut self, path_token: PathToken) -> &mut Self
pub fn push(&mut self, path_token: PathToken) -> &mut Self
Mutates this path by pushing a path token onto the end.
Sourcepub fn push_path(&mut self, path: &DocPath) -> &mut Self
pub fn push_path(&mut self, path: &DocPath) -> &mut Self
Mutates this path by pushing another path onto the end. Will drop the root marker from the other path
Sourcepub fn to_lower_case(&self) -> DocPath
pub fn to_lower_case(&self) -> DocPath
Returns a copy of this path will all parts lower case
Sourcepub fn as_json_pointer(&self) -> Result<String>
pub fn as_json_pointer(&self) -> Result<String>
Converts this path into a JSON pointer RFC6901.
Sourcepub fn ends_with(&self, suffix: &str) -> bool
pub fn ends_with(&self, suffix: &str) -> bool
If this path (as a string) ends with the given string
Sourcepub fn starts_with(&self, prefix: &str) -> bool
pub fn starts_with(&self, prefix: &str) -> bool
If this path (as a string) starts with the given string