Module v4

Module v4 

V4 specification models

Modules

async_message
Models for asynchronous message interactions
http_parts
V4 specification models - HTTP parts for SynchronousHttp
interaction
V4 Pact interaction
message_parts
Structs for shared parts of message interactions
pact
V4 specification Pact
sync_message
Synchronous interactions as a request message to a sequence of response messages
synch_http
Synchronous HTTP interactions

Enums

V4InteractionType
V4 Interaction Type

Functions

calc_content_type
Calculate the context type of the body, using the content type from the body. If that is not set, look for a Content-Type header otherwise look at the body contents