pub struct MatchingRuleCategory {
pub name: Category,
pub rules: HashMap<DocPath, RuleList>,
}Expand description
Data structure for representing a category of matching rules
Fields
name: CategoryName of the category
rules: HashMap<DocPath, RuleList>Matching rules for this category
Implementations
Sourceimpl MatchingRuleCategory
impl MatchingRuleCategory
Sourcepub fn empty<S>(name: S) -> MatchingRuleCategory
pub fn empty<S>(name: S) -> MatchingRuleCategory
Creates an empty category
Sourcepub fn equality<S>(name: S) -> MatchingRuleCategory
pub fn equality<S>(name: S) -> MatchingRuleCategory
Creates a default category
Sourcepub fn is_not_empty(&self) -> bool
pub fn is_not_empty(&self) -> bool
If the matching rules in the category are not empty
Sourcepub fn rule_from_json(
&mut self,
key: DocPath,
matcher_json: &Value,
rule_logic: RuleLogic,
) -> Result<()>
pub fn rule_from_json( &mut self, key: DocPath, matcher_json: &Value, rule_logic: RuleLogic, ) -> Result<()>
Adds a rule from the Value representation
Sourcepub fn add_rule(
&mut self,
key: DocPath,
matcher: MatchingRule,
rule_logic: RuleLogic,
)
pub fn add_rule( &mut self, key: DocPath, matcher: MatchingRule, rule_logic: RuleLogic, )
Adds a rule to this category
Sourcepub fn filter<F>(&self, predicate: F) -> MatchingRuleCategory
pub fn filter<F>(&self, predicate: F) -> MatchingRuleCategory
Filters the matchers in the category by the predicate, and returns a new category
Sourcepub fn to_v3_json(&self) -> Value
pub fn to_v3_json(&self) -> Value
Returns a JSON Value representation in V3 format
Sourcepub fn to_v2_json(&self) -> HashMap<String, Value>
pub fn to_v2_json(&self) -> HashMap<String, Value>
Returns a JSON Value representation in V2 format
Sourcepub fn type_matcher_defined(&self) -> bool
pub fn type_matcher_defined(&self) -> bool
If there is a type matcher defined for the category
Sourcepub fn values_matcher_defined(&self) -> bool
pub fn values_matcher_defined(&self) -> bool
If there is a values matcher defined in the rules
Sourcepub fn matcher_is_defined(&self, path: &[&str]) -> bool
pub fn matcher_is_defined(&self, path: &[&str]) -> bool
If there is a matcher defined for the path
Sourcepub fn resolve_matchers_for_path(&self, path: &[&str]) -> MatchingRuleCategory
pub fn resolve_matchers_for_path(&self, path: &[&str]) -> MatchingRuleCategory
filters this category with all rules that match the given path for categories that contain collections (eg. bodies, headers, query parameters). Returns self otherwise.
Sourcepub fn select_best_matcher(&self, path: &[&str]) -> RuleList
pub fn select_best_matcher(&self, path: &[&str]) -> RuleList
Selects the best matcher for the given path by calculating a weighting for each one
Sourcepub fn as_rule_list(&self) -> RuleList
pub fn as_rule_list(&self) -> RuleList
Returns this category as a matching rule list. Returns a None if there are no rules
Sourcepub fn add_rules_from_json(&mut self, rules: &Value) -> Result<()>
pub fn add_rules_from_json(&mut self, rules: &Value) -> Result<()>
Adds the rules to the category from the provided JSON
Sourcepub fn add_v3_rules_from_json(&mut self, rules: &Value) -> Result<()>
pub fn add_v3_rules_from_json(&mut self, rules: &Value) -> Result<()>
Adds the rules to the category from the provided JSON in V3+ format
Sourcepub fn generators(&self) -> HashMap<DocPath, Generator>
pub fn generators(&self) -> HashMap<DocPath, Generator>
Returns any generators associated with these matching rules
Sourcepub fn add_rules(&mut self, category: MatchingRuleCategory)
pub fn add_rules(&mut self, category: MatchingRuleCategory)
Add all the rules from the provided rules