V4 specification models
Modules
- async_
message - Models for asynchronous message interactions
- http_
parts - V4 specification models - HTTP parts for SynchronousHttp
- interaction
- V4 Pact interaction
- message_
parts - Structs for shared parts of message interactions
- pact
- V4 specification Pact
- sync_
message - Synchronous interactions as a request message to a sequence of response messages
- synch_
http - Synchronous HTTP interactions
Enums
- V4Interaction
Type - V4 Interaction Type
Functions
- calc_
content_ type - Calculate the context type of the body, using the content type from the body. If that is not set, look for a Content-Type header otherwise look at the body contents